# Extensible Calendar + Ext Scheduler

This is a combination example that makes use of the excellent third-party Ext Scheduler component. You can update the "staff" field in the calendar events or drag an event from one person to another within the scheduler to reassign it. The "location" field can also be updated in either component (you have to go to the details form in the calendar to update it) and it will automatically be reflected in both.

Note that Ext Scheduler is a commercial component, and the version included here by permission is an evaluation copy. Please visit ext-scheduler.com to see more examples of the scheduler component in action.

View the source